# -*- coding:utf-8 -*-
import pycurl,StringIO,urllib,sys,os
sys.path.append("..")
from hs_logController import LogController


class CurlHttpController:
    def __init__(self):
        self.c = pycurl.Curl()
        self.lc = LogController.LogController("chc")
        
    def __del__(self):
        self.c.close()

    def getContent(self,url,method="GET",data=None,header=[],cookie = ""):
        '''
        发起网络请求\n
        url:请求路由\n
        method:请求方法，GET/POST/PATCH/PUT/DELETE\n
        data:请求体参数\n
        header:请求头部信息\n
        cookie:请求携带cookie\n
        '''
        self.lc.info("req:`method:%s`header:%s`cookie:%s`data:%s`url:%s`" % (method,header,cookie,data,url))
        if len(header) != 0:
            self.c.setopt(pycurl.HTTPHEADER,header)
            
        if len(cookie) != 0:
            self.c.setopt(pycurl.COOKIE, cookie)
        
        self.c.setopt(pycurl.URL,str(url))
        self.c.setopt(pycurl.FOLLOWLOCATION, 0)

        if method in ("POST","PATCH","PUT","DELETE") :
            if not data:
                data="{}"
            try:
                self.c.setopt(pycurl.POSTFIELDS, data)
                
            except Exception,e:
                print "Data Error:",str(e)


        respContents = StringIO.StringIO()
        respHeaders = StringIO.StringIO()
        

        self.c.setopt(pycurl.CONNECTTIMEOUT, 5)    #连接的等待时间，设置为0则不等待 
        self.c.setopt(pycurl.TIMEOUT, 600)           #请求超时时间  
        self.c.setopt(pycurl.DNS_CACHE_TIMEOUT,60) #设置保存DNS信息的时间，默认为120秒  
        self.c.setopt(pycurl.SSL_VERIFYPEER, 0)   
        self.c.setopt(pycurl.SSL_VERIFYHOST, 0)

        
        self.c.setopt(pycurl.WRITEFUNCTION, respContents.write)
        self.c.setopt(pycurl.HEADERFUNCTION, respHeaders.write)
        self.c.setopt(pycurl.CUSTOMREQUEST, method)

        # pycurl.NAMELOOKUP_TIME 域名解析时间
        # pycurl.CONNECT_TIME 远程服务器连接时间
        # pycurl.PRETRANSFER_TIME 连接上后到开始传输时的时间
        # pycurl.STARTTRANSFER_TIME 接收到第一个字节的时间
        # pycurl.TOTAL_TIME 上一请求总的时间
        # pycurl.REDIRECT_TIME 如果存在转向的话，花费的时间
        # pycurl.SIZE_DOWNLOAD 下载的数据大小
     
        try:
            self.c.perform()
        except Exception,e:
            print str(e)
            
        namelookupTime = self.c.getinfo(pycurl.NAMELOOKUP_TIME)
        httpConnTime =  self.c.getinfo(pycurl.CONNECT_TIME)
        httpPreTran =  self.c.getinfo(pycurl.PRETRANSFER_TIME)
        httpStartTran =  self.c.getinfo(pycurl.STARTTRANSFER_TIME)
        httpTotalTime = self.c.getinfo(pycurl.TOTAL_TIME)
        httpSize = self.c.getinfo(pycurl.SIZE_DOWNLOAD)
        httpCode = self.c.getinfo(pycurl.HTTP_CODE)      
        totalTime =  int(self.c.getinfo(pycurl.TOTAL_TIME) * 1000)

        respContent = respContents.getvalue()
        respHeader = respHeaders.getvalue()

        

        respContents.close()
        respHeaders.close()
        
        self.lc.info("resp:`httpCode:%s`totalTime:%s`respContent:%s`respHeader:%s`namelookupTime:%s`httpConnTime:%s`httpPreTran:%s`httpStartTran:%s`httpTotalTime:%s`httpSize:%s" % (httpCode,totalTime,respContent,respHeader,namelookupTime,httpConnTime,httpPreTran,httpStartTran,httpTotalTime,httpSize))
        
        return httpCode,totalTime,respContent,respHeader,namelookupTime,httpConnTime,httpPreTran,httpStartTran,httpTotalTime,httpSize
    

# a = CurlHttpController()
# a.getContent("http://www.baidu.com")


# -*- coding:utf-8 -*-
import os

import logging

from logging.handlers import TimedRotatingFileHandler



class LogController(logging.Logger):

    CURRENT_PATH = os.path.dirname(os.path.abspath(__file__))
    print "CURRENT_PATH:",CURRENT_PATH
    ROOT_PATH = os.path.join(CURRENT_PATH, os.pardir)
    print "ROOT_PATH:",ROOT_PATH
    # LOG_PATH = os.path.join(CURRENT_PATH, 'log')
    LOG_PATH = os.path.join(ROOT_PATH, 'log')
    print "LOG_PATH:",LOG_PATH

    def __init__(self, name, level="DEBUG", stream=True, file=True):
        self.name = name
        self.level = level
        logging.Logger.__init__(self, self.name, level=level)
        if stream:
            self.__setStreamHandler__()
        if file:
            self.__setFileHandler__()

    def __setFileHandler__(self, level=None):
        """
        set file handler
        :param level:
        :return:
        """
        # file_name = os.path.join(self.LOG_PATH, '{name}.log'.format(name=self.name))
        file_name = os.path.join('.\\', '{name}.log'.format(name=self.name))
        
        # 设置日志回滚, 保存在log目录, 一天保存一个文件, 保留15天
        file_handler = TimedRotatingFileHandler(filename=file_name, when='D', interval=1, backupCount=15)
        file_handler.suffix = '%Y%m%d.log'
        if not level:
            file_handler.setLevel(self.level)
        else:
            file_handler.setLevel(level)
        formatter = logging.Formatter('%(asctime)s %(filename)s[line:%(lineno)d] %(levelname)s %(message)s')

        file_handler.setFormatter(formatter)
        self.file_handler = file_handler
        self.addHandler(file_handler)

    def __setStreamHandler__(self, level=None):

        stream_handler = logging.StreamHandler()
        # %(levelno)s: 打印日志级别的数值
        # %(levelname)s: 打印日志级别名称
        # %(pathname)s: 打印当前执行程序的路径，其实就是sys.argv[0]
        # %(filename)s: 打印当前执行程序名
        # %(funcName)s: 打印日志的当前函数
        # %(lineno)d: 打印日志的当前行号
        # %(asctime)s: 打印日志的时间
        # %(thread)d: 打印线程ID
        # %(threadName)s: 打印线程名称
        # %(process)d: 打印进程ID
        # %(message)s: 打印日志信息
        formatter = logging.Formatter('%(asctime)s %(filename)s[line:%(lineno)d] %(levelname)s %(message)s')
        stream_handler.setFormatter(formatter)
        if not level:
            stream_handler.setLevel(self.level)
        else:
            stream_handler.setLevel(level)
        self.addHandler(stream_handler)

    def resetName(self, name):
        """
        reset name
        :param name:
        :return:
        """
        self.name = name
        self.removeHandler(self.file_handler)
        self.__setFileHandler__()


# if __name__ == '__main__':
#     log = LogController('test')
#     log.info('this is a test msg')


# -*- coding:utf-8 -*-
import os
from setuptools import setup

# 第三方依赖
requires = [
    # "pandas>=0.23.4"
    "pycurl",
    "redis",
    "kafka",
    "logging"
]

setup(
    name="hs_package",  # 包名称
    version="0.0.7",  # 包版本
    description="hs_httpController provides http protocol network request\n hs_logController provides log output control\n",  # 包详细描述
    long_description="",   # 长描述，通常是readme，打包到PiPy需要
    author="hongs",  # 作者名称
    author_email="li_shengyou@163.com",  # 作者邮箱
    url="hs_httpController supports http protocol GET/POST/PATCH/PUT/DELETE method, the connection waiting time is 5s by default\n",   # 项目官网
    packages=["hs_httpController","hs_logController"],    # 项目需要的包
    install_requires=requires,  # 第三方库依赖
    zip_safe=False  # 此项需要，否则卸载时报windows error
)